API Reference
=============

This page provides an auto-generated summary of intake-esm’s API.
For more details and examples, refer to the relevant chapters in the main part of the documentation.


ESM Datastore (intake.open_esm_datastore)
~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~

.. module:: intake_esm.core

.. autoclass:: esm_datastore

   .. automethod:: __getitem__
   .. automethod:: from_df
   .. automethod:: to_dataset_dict
   .. automethod:: nunique
   .. automethod:: unique
   .. automethod:: search
   .. automethod:: serialize
